--------------------------------------------------------------------------------
-- Weapon Bow + Projectile Arrow
-- Carnage Contest Weapon
-- Script by Royal Flash, Sep 2009, www.UnrealSoftware.de
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.bbow={}
cc.bbow.arrow={}

-- Load & Prepare Ressources
cc.bbow.gfx_wpn0=loadgfx("royalweapons/bbow0.bmp")					-- Weapon Image Frame 0
setmidhandle(cc.bbow.gfx_wpn0)
cc.bbow.gfx_wpn1=loadgfx("royalweapons/bbow1.bmp")					-- Weapon Image Frame 1
setmidhandle(cc.bbow.gfx_wpn1)
cc.bbow.gfx_pro=loadgfx("royalweapons/barrow.bmp")					-- Projectile Image
setmidhandle(cc.bbow.gfx_pro)
cc.bbow.sfx_attack=loadsfx("arrow_shoot.ogg")				-- Attack Sound
cc.bbow.sfx_impact=loadsfx("arrow_impact.ogg")				-- Impact Sound

--------------------------------------------------------------------------------
-- Weapon: Explosivebow
--------------------------------------------------------------------------------

cc.bbow.id=addweapon("cc.bbow","Explosive Bow",cc.bbow.gfx_wpn0,3)		-- Add Weapon (3 uses)
cc.bbow.ammo=5											-- 5 arrows

function cc.bbow.draw()										-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	if cc.bbow.ammo-weapon_shots>0 and weapon_timer<=0 then
		drawinhand(cc.bbow.gfx_wpn1,6,0)
	else
		drawinhand(cc.bbow.gfx_wpn0,6,0)
	end
	-- Arrow
	if cc.bbow.ammo-weapon_shots>0 and weapon_timer<=0 and getplayeraction(0)==0 then
		setrotation(getplayerrotation(0))
		setscale(getplayerdirection(0),1)
		drawimage(cc.bbow.gfx_pro,getplayerx(0)+7*getplayerdirection(0),getplayery(0)+3)
	end
	-- HUD ammobar
	if cc.bbow.ammo-weapon_shots>0 then
		hudammobar(cc.bbow.ammo-weapon_shots,cc.bbow.ammo)
	end
	-- HUD Crosshair
	if cc.bbow.ammo-weapon_shots>0 then
		hudcrosshair(7,3)
	end
end

function cc.bbow.attack(attack)								-- Attack
	-- Decrement timer
	if weapon_timer>0 then
		weapon_timer=weapon_timer-1
	end
	-- Attack
	if weapon_shots<cc.bbow.ammo and weapon_timer<=0 and attack==1 then
		-- No more weapon switching!
		useweapon(0)
		-- Reset Timer
		weapon_timer=30
		-- Attack
		playsound(cc.bbow.sfx_attack)
		weapon_shots=weapon_shots+1
		id=createprojectile(cc.bbow.arrow.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+(7*getplayerdirection(0))-math.sin(math.rad(getplayerrotation(0)))*5.0
		projectiles[id].y=getplayery(0)+3+math.cos(math.rad(getplayerrotation(0)))*5.0
		-- Set speed of projectile
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*9.0
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*9.0
		-- Initial movement
		projectiles[id].x=projectiles[id].x-projectiles[id].sx*1.0
		projectiles[id].y=projectiles[id].y-projectiles[id].sy*1.0
		for i=1,3,1 do
			if cc.bbow.arrow.move(id)==1 then
				break
			end
		end
		-- Effects

		-- End Turn
		if (weapon_shots>=cc.bbow.ammo) then
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: arrow
--------------------------------------------------------------------------------

cc.bbow.arrow.id=addprojectile("cc.bbow.arrow")		-- Add Projectile

function cc.bbow.arrow.draw()							-- Draw
	id=projectileid()
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.bbow.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.bbow.arrow.update()							-- Update
	id=projectileid()
	-- Particle Tail
	particle(p_smoke,projectiles[id].x-math.sin(math.rad(rot))*7,projectiles[id].y+math.cos(math.rad(rot))*7)
	particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
	particlefadealpha(0.01)
	-- Wind + Gravity influence on speed
	projectiles[id].sx=projectiles[id].sx+getwind()*0.1
	projectiles[id].sy=projectiles[id].sy+getgravity()*1.5
	-- Move
	cc.bbow.arrow.move(id)
end

function cc.bbow.arrow.move(id)
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby		
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*8,projectiles[id].y-math.cos(math.rad(rot))*8,1,1)==1 then	
			if terraincollision()==1 or playercollision()~=projectiles[id].ignore then
				if playercollision()~=0 then
				-- Cause damage
				arealdamage(projectiles[id].x,projectiles[id].y,70,20)
				-- Destroy terrain
				terrainexplosion(projectiles[id].x,projectiles[id].y,25,1)

				else


	
				-- Cause damage
				arealdamage(projectiles[id].x,projectiles[id].y,70,20)
				-- Destroy terrain
				terrainexplosion(projectiles[id].x,projectiles[id].y,25,1)
				-- Crater
				grey=math.random(0,40)
				if math.random(0,1)==1 then
					terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
				else
					terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
				end
end
		-- Particles
		particle(p_muzzle,projectiles[id].x,projectiles[id].y)
		particlecolor(255,255,255)
		for angle=0,350,10 do
			particle(p_smoke,projectiles[id].x,projectiles[id].y)
			particlespeed(math.sin(math.rad(angle))*2,-math.cos(math.rad(angle))*2)
			particlecolor(255,255,255)
		end
				-- Effects
				playsound(cc.bbow.sfx_impact)
				particle(p_smoke,projectiles[id].x+math.sin(math.rad(rot))*21,projectiles[id].y-math.cos(math.rad(rot))*21)
				particlefadealpha(0.006)
				particle(p_muzzle,projectiles[id].x+math.sin(math.rad(rot))*21,projectiles[id].y-math.cos(math.rad(rot))*21)
				-- Free projectile
				freeprojectile(id)
				return 1
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			if math.random(1,2)==1 then
				playsound(sfx_hitwater2)
			else
				playsound(sfx_hitwater3)
			end
			-- Free projectile
			freeprojectile(id)
			return 1
		end
	end
end
