--------------------------------------------------------------------------------
-- Weapon Bow + Projectile Arrow
-- Carnage Contest Weapon
-- Script by Royal Flash, Sep 2009, www.UnrealSoftware.de
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.frbow={}
cc.frbow.arrow={}

-- Load & Prepare Ressources
cc.frbow.gfx_wpn0=loadgfx("royalweapons/frbow0.bmp")					-- Weapon Image Frame 0
setmidhandle(cc.frbow.gfx_wpn0)
cc.frbow.gfx_wpn1=loadgfx("royalweapons/frbow1.bmp")					-- Weapon Image Frame 1
setmidhandle(cc.frbow.gfx_wpn1)
cc.frbow.gfx_pro=loadgfx("royalweapons/arrowice.bmp")					-- Projectile Image
setmidhandle(cc.frbow.gfx_pro)
cc.frbow.sfx_attack=loadsfx("arrow_shoot.ogg")				-- Attack Sound
cc.frbow.sfx_impact=loadsfx("freeze.wav")				-- Impact Sound

--------------------------------------------------------------------------------
-- Weapon: Frozenbow
--------------------------------------------------------------------------------

cc.frbow.id=addweapon("cc.frbow","Frozen Bow",cc.frbow.gfx_wpn0,3)		-- Add Weapon (3 uses)
cc.frbow.ammo=2												-- 5 arrows

function cc.frbow.draw()										-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	if cc.frbow.ammo-weapon_shots>0 and weapon_timer<=0 then
		drawinhand(cc.frbow.gfx_wpn1,6,0)
	else
		drawinhand(cc.frbow.gfx_wpn0,6,0)
	end
	-- Arrow
	if cc.frbow.ammo-weapon_shots>0 and weapon_timer<=0 and getplayeraction(0)==0 then
		setrotation(getplayerrotation(0))
		setscale(getplayerdirection(0),1)
		drawimage(cc.frbow.gfx_pro,getplayerx(0)+7*getplayerdirection(0),getplayery(0)+3)
	end
	-- HUD ammobar
	if cc.frbow.ammo-weapon_shots>0 then
		hudammobar(cc.frbow.ammo-weapon_shots,cc.frbow.ammo)
	end
	-- HUD Crosshair
	if cc.frbow.ammo-weapon_shots>0 then
		hudcrosshair(7,3)
	end
end

function cc.frbow.attack(attack)								-- Attack
	-- Decrement timer
	if weapon_timer>0 then
		weapon_timer=weapon_timer-1
	end
	-- Attack
	if weapon_shots<cc.frbow.ammo and weapon_timer<=0 and attack==1 then
		-- No more weapon switching!
		useweapon(0)
		-- Reset Timer
		weapon_timer=30
		-- Attack
		playsound(cc.frbow.sfx_attack)
		weapon_shots=weapon_shots+1
		id=createprojectile(cc.frbow.arrow.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+(7*getplayerdirection(0))-math.sin(math.rad(getplayerrotation(0)))*5.0
		projectiles[id].y=getplayery(0)+3+math.cos(math.rad(getplayerrotation(0)))*5.0
		-- Set speed of projectile
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*9.0
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*9.0
		-- Initial movement
		projectiles[id].x=projectiles[id].x-projectiles[id].sx*1.0
		projectiles[id].y=projectiles[id].y-projectiles[id].sy*1.0
		for i=1,3,1 do
			if cc.frbow.arrow.move(id)==1 then
				break
			end
		end
		-- Effects

		-- End Turn
		if (weapon_shots>=cc.frbow.ammo) then
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: arrow
--------------------------------------------------------------------------------

cc.frbow.arrow.id=addprojectile("cc.frbow.arrow")		-- Add Projectile

function cc.frbow.arrow.draw()							-- Draw
	id=projectileid()
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.frbow.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.frbow.arrow.update()							-- Update
	id=projectileid()
	-- Particle Tail
	particle(p_smoke,projectiles[id].x,projectiles[id].y)
	particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
	particlecolor(255,255,255)
	-- Wind + Gravity influence on speed
	projectiles[id].sx=projectiles[id].sx+getwind()*0.1
	projectiles[id].sy=projectiles[id].sy+getgravity()*1.5
	-- Move
	cc.frbow.arrow.move(id)
end

function cc.frbow.arrow.move(id)
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby		
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*8,projectiles[id].y-math.cos(math.rad(rot))*8,1,1)==1 then	
			if terraincollision()==1 or playercollision()~=projectiles[id].ignore then
		blue=math.random(200,255)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		end
				if playercollision()~=0 then
					-- Cause damage
					playerpush(playercollision(),projectiles[id].sx/10.0,projectiles[id].sy/10.0)
					playerdamage(playercollision(),15)
					blood(projectiles[id].x+math.sin(math.rad(rot))*8,projectiles[id].y-math.cos(math.rad(rot))*8)
					playsound(sfx_splatter3)
					players=playertable()
					for i=1,#players,1 do
						if getplayerhealth(players[i])>0 then
							if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=45 then
					playerstate(players[i],state_frozen,1)
				end
			end
		end
				else


		-- Crater
		blue=math.random(200,255)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		end

					-- Freeze Players
					players=playertable()
					for i=1,#players,1 do
						if getplayerhealth(players[i])>0 then
							if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=45 then
					playerstate(players[i],state_frozen,1)
				end
			end
		end

					-- Draw Arrow in terrain
					terrainimage(cc.frbow.gfx_pro,projectiles[id].x,projectiles[id].y,0,rot)
				end

		-- Particles
		particle(p_muzzle,projectiles[id].x,projectiles[id].y)
		particlecolor(255,255,255)
		for angle=0,350,10 do
			particle(p_smoke,projectiles[id].x,projectiles[id].y)
			particlespeed(math.sin(math.rad(angle))*2,-math.cos(math.rad(angle))*2)
			particlecolor(255,255,255)
		end
				-- Effects
				playsound(cc.frbow.sfx_impact)
				particle(p_smoke,projectiles[id].x+math.sin(math.rad(rot))*21,projectiles[id].y-math.cos(math.rad(rot))*21)
				particlefadealpha(0.006)
				particle(p_muzzle,projectiles[id].x+math.sin(math.rad(rot))*21,projectiles[id].y-math.cos(math.rad(rot))*21)
				-- Free projectile
				freeprojectile(id)
				return 1
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			if math.random(1,2)==1 then
				playsound(sfx_hitwater2)
			else
				playsound(sfx_hitwater3)
			end
			-- Free projectile
			freeprojectile(id)
			return 1
		end
	end
end
