--------------------------------------------------------------------------------
-- Weapon Bow + Projectile Arrow
-- Carnage Contest Weapon
-- Script by Royal Flash, Sep 2009, www.UnrealSoftware.de
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.pbow={}
cc.pbow.arrow={}

-- Load & Prepare Ressources
cc.pbow.gfx_wpn0=loadgfx("royalweapons/pbow0.bmp")					-- Weapon Image Frame 0
setmidhandle(cc.pbow.gfx_wpn0)
cc.pbow.gfx_wpn1=loadgfx("royalweapons/pbow1.bmp")					-- Weapon Image Frame 1
setmidhandle(cc.pbow.gfx_wpn1)
cc.pbow.gfx_pro=loadgfx("royalweapons/Poisonarrow.bmp")					-- Projectile Image
setmidhandle(cc.pbow.gfx_pro)
cc.pbow.sfx_attack=loadsfx("arrow_shoot.ogg")				-- Attack Sound
cc.pbow.sfx_impact=loadsfx("arrow_impact.ogg")				-- Impact Sound

--------------------------------------------------------------------------------
-- Weapon: Poisonbow
--------------------------------------------------------------------------------

cc.pbow.id=addweapon("cc.pbow","Poison Bow",cc.pbow.gfx_wpn0,3)		-- Add Weapon (3 uses)
cc.pbow.ammo=5												-- 5 arrows

function cc.pbow.draw()										-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	if cc.pbow.ammo-weapon_shots>0 and weapon_timer<=0 then
		drawinhand(cc.pbow.gfx_wpn1,6,0)
	else
		drawinhand(cc.pbow.gfx_wpn0,6,0)
	end
	-- Arrow
	if cc.pbow.ammo-weapon_shots>0 and weapon_timer<=0 and getplayeraction(0)==0 then
		setrotation(getplayerrotation(0))
		setscale(getplayerdirection(0),1)
		drawimage(cc.pbow.gfx_pro,getplayerx(0)+7*getplayerdirection(0),getplayery(0)+3)
	end
	-- HUD ammobar
	if cc.pbow.ammo-weapon_shots>0 then
		hudammobar(cc.pbow.ammo-weapon_shots,cc.pbow.ammo)
	end
	-- HUD Crosshair
	if cc.pbow.ammo-weapon_shots>0 then
		hudcrosshair(7,3)
	end
end

function cc.pbow.attack(attack)								-- Attack
	-- Decrement timer
	if weapon_timer>0 then
		weapon_timer=weapon_timer-1
	end
	-- Attack
	if weapon_shots<cc.pbow.ammo and weapon_timer<=0 and attack==1 then
		-- No more weapon switching!
		useweapon(0)
		-- Reset Timer
		weapon_timer=30
		-- Attack
		playsound(cc.pbow.sfx_attack)
		weapon_shots=weapon_shots+1
		id=createprojectile(cc.pbow.arrow.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+(7*getplayerdirection(0))-math.sin(math.rad(getplayerrotation(0)))*5.0
		projectiles[id].y=getplayery(0)+3+math.cos(math.rad(getplayerrotation(0)))*5.0
		-- Set speed of projectile
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*9.0
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*9.0
		-- Initial movement
		projectiles[id].x=projectiles[id].x-projectiles[id].sx*1.0
		projectiles[id].y=projectiles[id].y-projectiles[id].sy*1.0
		for i=1,3,1 do
			if cc.pbow.arrow.move(id)==1 then
				break
			end
		end
		-- Effects

		-- End Turn
		if (weapon_shots>=cc.pbow.ammo) then
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: arrow
--------------------------------------------------------------------------------

cc.pbow.arrow.id=addprojectile("cc.pbow.arrow")		-- Add Projectile

function cc.pbow.arrow.draw()							-- Draw
	id=projectileid()
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.pbow.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.pbow.arrow.update()							-- Update
	id=projectileid()
	-- Particle Tail
	particle(p_smoke,projectiles[id].x,projectiles[id].y)
	particlecolor(0,255,0)
	particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
	particlefadealpha(0.01)
	particle(p_lightpuff,projectiles[id].x,projectiles[id].y)
	particlecolor(0,255,0)
	particlefadealpha(0.04)
	-- Wind + Gravity influence on speed
	projectiles[id].sx=projectiles[id].sx+getwind()*0.1
	projectiles[id].sy=projectiles[id].sy+getgravity()*1.5
	-- Move
	cc.pbow.arrow.move(id)
end

function cc.pbow.arrow.move(id)
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby		
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*8,projectiles[id].y-math.cos(math.rad(rot))*8,1,1)==1 then
		if terraincollision()==1 or playercollision()~=projectiles[id].ignore then	
		players=playertable()
		for i=1,#players,1 do
			if getplayerhealth(players[i])>0 then
				if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=70 then
					playerstate(players[i],state_poisoned,1)
				end
			end
		end
		if playercollision()~=0 then

		-- Poison Players
		players=playertable()
		for i=1,#players,1 do
			if getplayerhealth(players[i])>0 then
				if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=70 then
					playerstate(players[i],state_poisoned,1)
				end
			end
		end
					-- Cause damage
					playerpush(playercollision(),projectiles[id].sx/10.0,projectiles[id].sy/10.0)
					playerdamage(playercollision(),5)
					blood(projectiles[id].x+math.sin(math.rad(rot))*8,projectiles[id].y-math.cos(math.rad(rot))*8)
					playsound(sfx_splatter3)
				else
					-- Draw Arrow in terrain
					terrainimage(cc.pbow.gfx_pro,projectiles[id].x,projectiles[id].y,0,rot)
				end

				-- Effects
				playsound(cc.pbow.sfx_impact)
		particle(p_smoke,projectiles[id].x,projectiles[id].y)
		particlealpha(0.5)
		particlecolor(0,255,0)
		particlesize(10,10)
		particlefadealpha(0.005)
		for angle=10,340,10 do
		particle(p_smoke,projectiles[id].x,projectiles[id].y)
		particlespeed(math.sin(math.rad(angle))*0.5,-math.cos(math.rad(angle))*0.5)
		particlealpha(1.0)
		particlecolor(0,255,0)
		particlesize(5,5)
		particlefadealpha(0.009)
end
				-- Free projectile
				freeprojectile(id)
				return 1
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			if math.random(1,2)==1 then
				playsound(sfx_hitwater2)
			else
				playsound(sfx_hitwater3)
			end
			-- Free projectile
			freeprojectile(id)
			return 1
		end
	end
end
